@@ -1,6 +1,6 @@
 /*******************************************************************************
  * 
- * Copyright (c) 2009, 2010, Barthelemy Dagenais All rights reserved.
+ * Copyright (c) 2009, 2011, Barthelemy Dagenais All rights reserved.
  * 
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
@@ -29,6 +29,9 @@
  *******************************************************************************/
 package py4j;
 
+import java.io.PrintWriter;
+import java.io.StringWriter;
+import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Proxy;
 
 import py4j.reflection.PythonProxyHandler;
@@ -90,6 +93,7 @@ public class Protocol {
 	public final static char SET_TYPE = 'h';
 	public final static char ARRAY_TYPE = 't';
 	public final static char MAP_TYPE = 'a';
+	public final static char ITERATOR_TYPE = 'g';
 	public final static char NULL_TYPE = 'n';
 	public final static char PYTHON_PROXY_TYPE = 'f';
 
@@ -116,6 +120,9 @@ public class Protocol {
 	// ENTRY POINT
 	public final static String ENTRY_POINT_OBJECT_ID = "t";
 
+	// DEFAULT JVM VIEW
+	public final static String DEFAULT_JVM_OBJECT_ID = "j";
+	
 	// STATIC REFERENCES
 	public final static String STATIC_PREFIX = "z:";
 
@@ -156,6 +163,18 @@ public class Protocol {
 	public final static int getInteger(String commandPart) {
 		return Integer.parseInt(commandPart.substring(1, commandPart.length()));
 	}
+	
+	/**
+	 * <p>
+	 * Assumes that commandPart is <b>not</b> empty.
+	 * </p>
+	 * 
+	 * @param commandPart
+	 * @return The long value corresponding to this command part.
+	 */
+	public final static long getLong(String commandPart) {
+		return Long.parseLong(commandPart.substring(1, commandPart.length()));
+	}
 
 	public final static String getMemberOutputCommand(char memberType) {
 		StringBuilder builder = new StringBuilder();
@@ -166,6 +185,17 @@ public class Protocol {
 
 		return builder.toString();
 	}
+	
+	public final static String getMemberOutputCommand(char memberType, String fqn) {
+		StringBuilder builder = new StringBuilder();
+
+		builder.append(SUCCESS);
+		builder.append(memberType);
+		builder.append(fqn);
+		builder.append(END_OUTPUT);
+
+		return builder.toString();
+	}
 
 	public static String getNoSuchFieldOutputCommand() {
 		return NO_SUCH_FIELD;
@@ -194,7 +224,11 @@ public class Protocol {
 			case DOUBLE_TYPE:
 				return getDouble(commandPart);
 			case INTEGER_TYPE:
-				return getInteger(commandPart);
+				try {
+					return getInteger(commandPart);
+				} catch (NumberFormatException e) {
+					return getLong(commandPart);
+				}
 			case NULL_TYPE:
 				return getNull(commandPart);
 			case VOID:
@@ -206,7 +240,7 @@ public class Protocol {
 			case PYTHON_PROXY_TYPE:
 				return getPythonProxy(commandPart, gateway);
 			default:
-				throw new Py4JException("Command Part is unknown.");
+				throw new Py4JException("Command Part is unknown: " + commandPart);
 			}
 		}
 	}
@@ -215,7 +249,7 @@ public class Protocol {
 		StringBuilder builder = new StringBuilder();
 
 		if (rObject.isError()) {
-			builder.append(ERROR);
+			builder.append(rObject.getCommandPart());
 		} else {
 			builder.append(SUCCESS);
 			builder.append(rObject.getCommandPart());
@@ -229,6 +263,52 @@ public class Protocol {
 		return ERROR_COMMAND;
 	}
 
+	public final static String getOutputErrorCommand(String errorMessage) {
+		StringBuilder builder = new StringBuilder();
+		builder.append(ERROR);
+		builder.append(Protocol.STRING_TYPE);
+		builder.append(StringUtil.escape(errorMessage));
+		builder.append(END_OUTPUT);
+		return builder.toString();
+	}
+
+	public final static String getOutputErrorCommand(Throwable throwable) {
+		StringBuilder builder = new StringBuilder();
+		builder.append(ERROR);
+		builder.append(Protocol.STRING_TYPE);
+		builder.append(StringUtil.escape(getThrowableAsString(throwable)));
+		builder.append(END_OUTPUT);
+		return builder.toString();
+	}
+
+	public final static Throwable getRootThrowable(Throwable throwable,
+			boolean skipInvocation) {
+		Throwable child = throwable;
+		if (!skipInvocation && child instanceof InvocationTargetException) {
+			child = throwable.getCause();
+			skipInvocation = true;
+		} else if (child instanceof Py4JException
+				|| child instanceof Py4JNetworkException) {
+			child = throwable.getCause();
+		} else {
+			return child;
+		}
+
+		if (child == null) {
+			return throwable;
+		} else {
+			return getRootThrowable(child, skipInvocation);
+		}
+	}
+
+	public final static String getThrowableAsString(Throwable throwable) {
+		Throwable root = getRootThrowable(throwable, false);
+		StringWriter stringWriter = new StringWriter();
+		PrintWriter printWriter = new PrintWriter(stringWriter);
+		root.printStackTrace(printWriter);
+		return stringWriter.toString();
+	}
+
 	public final static String getOutputVoidCommand() {
 		return VOID_COMMAND;
 	}
@@ -282,7 +362,7 @@ public class Protocol {
 
 		Object proxy = Proxy.newProxyInstance(gateway.getClass()
 				.getClassLoader(), interfaces, new PythonProxyHandler(parts[0],
-				gateway.getCommunicationChannelFactory(), gateway));
+				gateway.getCallbackClient(), gateway));
 
 		return proxy;
 	}
@@ -304,16 +384,18 @@ public class Protocol {
 
 		return gateway.getObject(reference);
 	}
-	
-	public final static Object getReturnValue(String returnMessage, Gateway gateway) {
+
+	public final static Object getReturnValue(String returnMessage,
+			Gateway gateway) {
 		Object returnValue = null;
-	
+
 		if (isError(returnMessage)) {
-			throw new Py4JException("An exception was raised by the Python Proxy.");
+			throw new Py4JException(
+					"An exception was raised by the Python Proxy.");
 		} else {
 			returnValue = getObject(returnMessage.substring(1), gateway);
 		}
-		
+
 		return returnValue;
 	}
 
